@@ -1,11 +1,11 @@
 #!/bin/sh
 ########################################################################
 #    
-#    (c) 2001-2004 Intersect Alliance Pty Ltd
+#    (c) 2001-2006 Intersect Alliance Pty Ltd
 # 
 #   This script will automate the installation of the snare audit daemon.
 #   
-#   Version 1.7
+#   Version 1.8
 #    
 #    Usage: ./install.sh
 #
@@ -142,16 +142,14 @@ check_os_and_patch_level()
    uname -r | grep 5.8 > /dev/null
    RETVAL=$?
 
-   if [ $RETVAL -lt 1 ]
-   then
+   if [ $RETVAL -lt 1 ]; then
 	echo "No additional patches are required for Solaris 8. Continuing."
    fi
 
    uname -r | grep 5.9 > /dev/null
    RETVAL=$?
 
-   if [ $RETVAL -lt 1 ]
-   then
+   if [ $RETVAL -lt 1 ]; then
 	echo "No additional patches are required for Solaris 9. Continuing."
    fi
 }
@@ -274,7 +272,7 @@ if [ -f /var/run/snarecore.pid ]; then
 	rm -f /var/run/snarecore.pid >/dev/null 2>&1
 fi
 
-while [ "$INSTAL" -ne "1" ] && [ "$INSTAL" -ne "2" ] && [ "$INSTAL" -ne "3" ]
+while [ "$INSTAL" -ne "1" ] && [ "$INSTAL" -ne "2" ] && [ "$INSTAL" -ne "3" ] && [ "$INSTAL" -ne "4" ]
 do
   echo 
   echo "Enter [1] to install a basic starting configuration:"
